Thank you for installing image downloader

You will need to parameters to run use the module.

- Image url
- Directory for the image to be downloaded
- Image name

Import function by : from fast_image_extract.website_one import download_images
